API Reference
=============

Directory
---------

.. autoclass:: dirlay.Dir
    :member-order: groupwise
    :members:
    :special-members: __contains__, __eq__, __getitem__, __iter__, __or__, __ior__, __enter__, __exit__

Node
----

.. autoclass:: dirlay.Node
    :members:

Utilities
---------

.. autofunction:: dirlay.getcwd

Type aliases
------------

>>> from dirlay.types import DictTree, DictNode

.. autodata:: dirlay.types.DictTree
    :annotation:

.. autodata:: dirlay.types.DictNode
    :annotation:
